@@ -1,7 +1,7 @@
 /*
  * fsarchiver: Filesystem Archiver
  *
- * Copyright (C) 2008-2012 Francois Dupoux.  All rights reserved.
+ * Copyright (C) 2008-2016 Francois Dupoux.  All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -21,7 +21,31 @@
 struct s_dico;
 struct s_strlist;
 
-#define XFS_SUPER_MAGIC 0x58465342
+/*
+ * Super block
+ * Fits into a sector-sized buffer at address 0 of each allocation group.
+ * Only the first of these is ever updated except during growfs.
+ */
+#define XFS_SB_MAGIC        0x58465342  /* 'XFSB' */
+#define XFS_SB_VERSION_1    1       /* 5.3, 6.0.1, 6.1 */
+#define XFS_SB_VERSION_2    2       /* 6.2 - attributes */
+#define XFS_SB_VERSION_3    3       /* 6.2 - new inode version */
+#define XFS_SB_VERSION_4    4       /* 6.2+ - bitmask version */
+#define XFS_SB_VERSION_5    5       /* CRC enabled filesystem */
+#define XFS_SB_VERSION_NUMBITS      0x000f
+#define XFS_SB_VERSION_ALLFBITS     0xfff0
+#define XFS_SB_VERSION_ATTRBIT      0x0010
+#define XFS_SB_VERSION_NLINKBIT     0x0020
+#define XFS_SB_VERSION_QUOTABIT     0x0040
+#define XFS_SB_VERSION_ALIGNBIT     0x0080
+#define XFS_SB_VERSION_DALIGNBIT    0x0100
+#define XFS_SB_VERSION_SHAREDBIT    0x0200
+#define XFS_SB_VERSION_LOGV2BIT     0x0400
+#define XFS_SB_VERSION_SECTORBIT    0x0800
+#define XFS_SB_VERSION_EXTFLGBIT    0x1000
+#define XFS_SB_VERSION_DIRV2BIT     0x2000
+#define XFS_SB_VERSION_BORGBIT      0x4000  /* ASCII only case-insens. */
+#define XFS_SB_VERSION_MOREBITSBIT  0x8000
 
 int xfs_mkfs(struct s_dico *d, char *partition, char *fsoptions);
 int xfs_getinfo(struct s_dico *d, char *devname);
@@ -29,15 +53,7 @@ int xfs_mount(char *partition, char *mntbuf, char *fsbuf, int flags, char *mntin
 int xfs_get_reqmntopt(char *partition, struct s_strlist *reqopt, struct s_strlist *badopt);
 int xfs_umount(char *partition, char *mntbuf);
 int xfs_test(char *devname);
-
-typedef uint8_t __u8;
-typedef int8_t __s8;
-typedef uint16_t __u16;
-typedef int16_t __s16;
-typedef uint32_t __u32;
-typedef int32_t __s32;
-typedef uint64_t __u64;
-typedef int64_t __s64;
+int xfs_check_compatibility(u64 compat, u64 ro_compat, u64 incompat, u64 log_incompat);
 
 typedef __uint32_t      xfs_agblock_t;  /* blockno in alloc. group */
 typedef __uint32_t      xfs_extlen_t;   /* extent length in blocks */
@@ -62,9 +78,9 @@ typedef __uint16_t      xfs_prid_t;     /* prid_t truncated to 16bits in XFS */
  * These types are 64 bits on disk but are either 32 or 64 bits in memory.
  * Disk based types:
  */
-typedef __uint64_t      xfs_dfsbno_t;   /* blockno in filesystem (agno|agbno) */
-typedef __uint64_t      xfs_drfsbno_t;  /* blockno in filesystem (raw) */
-typedef __uint64_t      xfs_drtbno_t;   /* extent (block) in realtime area */
+typedef __uint64_t      xfs_fsblock_t;  /* blockno in filesystem (agno|agbno) */
+typedef __uint64_t      xfs_rfsblock_t; /* blockno in filesystem (raw) */
+typedef __uint64_t      xfs_rtblock_t;  /* extent (block) in realtime area */
 typedef __uint64_t      xfs_dfiloff_t;  /* block number in a file */
 typedef __uint64_t      xfs_dfilblks_t; /* number of blocks in a file */
 
@@ -75,22 +91,19 @@ typedef char *          xfs_caddr_t;    /* <core address> type */
 typedef __u32           xfs_dev_t;
 typedef __u32           xfs_nlink_t;
 
-typedef struct { unsigned char   __u_bits[16]; } xfs_uuid_t;
-
-
 /*
  * Superblock - in core version.  Must match the ondisk version below.
  * Must be padded to 64 bit alignment.
  */
-struct xfs_sb 
+struct xfs_sb
 {
         __uint32_t      sb_magicnum;    /* magic number == XFS_SB_MAGIC */
         __uint32_t      sb_blocksize;   /* logical block size, bytes */
-        xfs_drfsbno_t   sb_dblocks;     /* number of data blocks */
-        xfs_drfsbno_t   sb_rblocks;     /* number of realtime blocks */
-        xfs_drtbno_t    sb_rextents;    /* number of realtime extents */
-        xfs_uuid_t      sb_uuid;        /* file system unique id */
-        xfs_dfsbno_t    sb_logstart;    /* starting block of log if internal */
+        xfs_rfsblock_t  sb_dblocks;     /* number of data blocks */
+        xfs_rfsblock_t  sb_rblocks;     /* number of realtime blocks */
+        xfs_rtblock_t   sb_rextents;    /* number of realtime extents */
+        uuid_t          sb_uuid;        /* user-visible file system unique id */
+        xfs_fsblock_t   sb_logstart;    /* starting block of log if internal */
         xfs_ino_t       sb_rootino;     /* root inode number */
         xfs_ino_t       sb_rbmino;      /* bitmap inode for realtime extents */
         xfs_ino_t       sb_rsumino;     /* summary inode for rt bitmap */
@@ -112,6 +125,7 @@ struct xfs_sb
         __uint8_t       sb_rextslog;    /* log2 of sb_rextents */
         __uint8_t       sb_inprogress;  /* mkfs is in progress, don't mount */
         __uint8_t       sb_imax_pct;    /* max % of fs for inode space */
+                                        /* statistics */
         /*
          * These fields must remain contiguous.  If you really
          * want to change their layout, make sure you fix the
@@ -137,15 +151,48 @@ struct xfs_sb
         __uint16_t      sb_logsectsize; /* sector size for the log, bytes */
         __uint32_t      sb_logsunit;    /* stripe unit size for the log */
         __uint32_t      sb_features2;   /* additional feature bits */
+
         /*
-         * bad features2 field as a result of failing to pad the sb
-         * structure to 64 bits. Some machines will be using this field
-         * for features2 bits. Easiest just to mark it bad and not use
-         * it for anything else.
+         * bad features2 field as a result of failing to pad the sb structure to
+         * 64 bits. Some machines will be using this field for features2 bits.
+         * Easiest just to mark it bad and not use it for anything else.
+         *
+         * This is not kept up to date in memory; it is always overwritten by
+         * the value in sb_features2 when formatting the incore superblock to
+         * the disk buffer.
          */
         __uint32_t      sb_bad_features2;
 
+        /* version 5 superblock fields start here */
+
+        /* feature masks */
+        __uint32_t      sb_features_compat;
+        __uint32_t      sb_features_ro_compat;
+        __uint32_t      sb_features_incompat;
+        __uint32_t      sb_features_log_incompat;
+
+        __uint32_t      sb_crc;         /* superblock crc */
+        xfs_extlen_t    sb_spino_align; /* sparse inode chunk alignment */
+
+        xfs_ino_t       sb_pquotino;    /* project quota inode */
+        xfs_lsn_t       sb_lsn;         /* last write sequence */
+        uuid_t          sb_meta_uuid;   /* metadata file system unique id */
+
         /* must be padded to 64 bit alignment */
 };
 
+// XFS features used in XFS version 5 only
+#define XFS_SB_FEAT_RO_COMPAT_FINOBT      (1 << 0)  /* free inode btree */
+#define XFS_SB_FEAT_INCOMPAT_FTYPE        (1 << 0)  /* filetype in dirent */
+#define XFS_SB_FEAT_INCOMPAT_SPINODES     (1 << 1)  /* sparse inode chunks */
+#define XFS_SB_FEAT_INCOMPAT_META_UUID    (1 << 2)  /* metadata UUID */
+
+// features supported by the current fsarchiver version
+#define FSA_XFS_FEATURE_COMPAT_SUPP       (u64)(0)
+#define FSA_XFS_FEATURE_RO_COMPAT_SUPP    (u64)(XFS_SB_FEAT_RO_COMPAT_FINOBT)
+#define FSA_XFS_FEATURE_INCOMPAT_SUPP     (u64)(XFS_SB_FEAT_INCOMPAT_FTYPE|\
+                                                XFS_SB_FEAT_INCOMPAT_SPINODES|\
+                                                XFS_SB_FEAT_INCOMPAT_META_UUID)
+#define FSA_XFS_FEATURE_LOG_INCOMPAT_SUPP (u64)(0)
+
 #endif // __FS_XFS_H__
